"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCountersUpdater = exports.getMessageUpdater = void 0;
const node_path_1 = __importDefault(require("node:path"));
const log_1 = require("./log");
const lineRewriter = new log_1.LineRewriter();
const getMessageUpdater = (configuration) => {
    const { isShowProgress } = configuration;
    if (!isShowProgress)
        return () => { };
    return (message) => lineRewriter.update([message]);
};
exports.getMessageUpdater = getMessageUpdater;
const getCountersUpdater = (configuration, counters) => {
    const { workingDir, isShowProgress, report } = configuration;
    if (!isShowProgress)
        return () => { };
    return (issue) => {
        if (!issue)
            return lineRewriter.resetLines();
        const { processed, total } = counters;
        const percentage = Math.floor((processed / total) * 100);
        const messages = [(0, log_1.getLine)(`${percentage}%`, `of files processed (${processed} of ${total})`)];
        report.files && messages.push((0, log_1.getLine)(counters.files, 'unused files'));
        report.unlisted && messages.push((0, log_1.getLine)(counters.unresolved, 'unlisted dependencies'));
        report.exports && messages.push((0, log_1.getLine)(counters.exports, 'unused exports'));
        report.nsExports && messages.push((0, log_1.getLine)(counters.nsExports, 'unused exports in namespace'));
        report.types && messages.push((0, log_1.getLine)(counters.types, 'unused types'));
        report.nsTypes && messages.push((0, log_1.getLine)(counters.nsTypes, 'unused types in namespace'));
        report.duplicates && messages.push((0, log_1.getLine)(counters.duplicates, 'duplicate exports'));
        if (processed < total) {
            messages.push('');
            messages.push(`Processing: ${node_path_1.default.relative(workingDir, issue.filePath)}`);
        }
        lineRewriter.update(messages);
    };
};
exports.getCountersUpdater = getCountersUpdater;
