"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const TRUNCATE_WIDTH = 40;
const logIssueLine = (issue, workingDir, maxWidth) => {
    const symbols = issue.symbols ? issue.symbols.join(', ') : issue.symbol;
    const truncatedSymbol = symbols.length > maxWidth ? symbols.slice(0, maxWidth - 3) + '...' : symbols;
    const filePath = node_path_1.default.relative(workingDir, issue.filePath);
    console.log(`${truncatedSymbol.padEnd(maxWidth + 2)}${issue.symbolType?.padEnd(11) || ''}${filePath}`);
};
const logIssueGroupResult = (issues, workingDir, title) => {
    title && console.log(`--- ${title} (${issues.length})`);
    if (issues.length) {
        issues.sort().forEach(value => console.log(value.startsWith('/') ? node_path_1.default.relative(workingDir, value) : value));
    }
    else {
        console.log('Not found');
    }
};
const logIssueGroupResults = (issues, workingDir, title, isTruncate = false) => {
    title && console.log(`--- ${title} (${issues.length})`);
    if (issues.length) {
        const sortedByFilePath = issues.sort((a, b) => (a.filePath > b.filePath ? 1 : -1));
        const maxWidth = isTruncate ? TRUNCATE_WIDTH : issues.reduce((max, issue) => Math.max(issue.symbol.length, max), 0);
        sortedByFilePath.forEach(issue => logIssueLine(issue, workingDir, maxWidth));
    }
    else {
        console.log('Not found');
    }
};
exports.default = ({ report, issues, workingDir, isDev }) => {
    const reportMultipleGroups = Object.values(report).filter(Boolean).length > 1;
    if (report.files) {
        const unreferencedFiles = Array.from(issues.files);
        logIssueGroupResult(unreferencedFiles, workingDir, reportMultipleGroups && 'UNUSED FILES');
    }
    if (report.dependencies) {
        const unreferencedDependencies = Array.from(issues.dependencies);
        logIssueGroupResult(unreferencedDependencies, workingDir, reportMultipleGroups && 'UNUSED DEPENDENCIES');
    }
    if (report.dependencies && isDev) {
        const unreferencedDevDependencies = Array.from(issues.devDependencies);
        logIssueGroupResult(unreferencedDevDependencies, workingDir, 'UNUSED DEV DEPENDENCIES');
    }
    if (report.unlisted) {
        const unresolvedDependencies = Object.values(issues.unresolved).map(Object.values).flat();
        logIssueGroupResults(unresolvedDependencies, workingDir, reportMultipleGroups && 'UNLISTED DEPENDENCIES');
    }
    if (report.exports) {
        const unreferencedExports = Object.values(issues.exports).map(Object.values).flat();
        logIssueGroupResults(unreferencedExports, workingDir, reportMultipleGroups && 'UNUSED EXPORTS');
    }
    if (report.nsExports) {
        const unreferencedNsExports = Object.values(issues.nsExports).map(Object.values).flat();
        logIssueGroupResults(unreferencedNsExports, workingDir, reportMultipleGroups && 'UNUSED EXPORTS IN NAMESPACE');
    }
    if (report.types) {
        const unreferencedTypes = Object.values(issues.types).map(Object.values).flat();
        logIssueGroupResults(unreferencedTypes, workingDir, reportMultipleGroups && 'UNUSED TYPES');
    }
    if (report.nsTypes) {
        const unreferencedNsTypes = Object.values(issues.nsTypes).map(Object.values).flat();
        logIssueGroupResults(unreferencedNsTypes, workingDir, reportMultipleGroups && 'UNUSED TYPES IN NAMESPACE');
    }
    if (report.duplicates) {
        const unreferencedDuplicates = Object.values(issues.duplicates).map(Object.values).flat();
        logIssueGroupResults(unreferencedDuplicates, workingDir, reportMultipleGroups && 'DUPLICATE EXPORTS', true);
    }
};
